# Cronitor

Monitor services through cron and notifiers.

## Implemented services

- postfix mail queue size
- mail TLS reports
- borg backups
- automysqlbackup
- amazon kindle quotes (publish quotes from Amazon Kindle on matrix)

## Implemented notifiers:

- stdout
- matrix
